# Artemis-lab (aka Artemis)

## Description
Artemis is the french acronym standing for "Atelier Reutilisable de Traitements d'Expertise Multi Images Satellitaires".
Its core can be defined as a python framework to play user's defined pipelines.
More coming soon... 

## License
Artemis will be distritued under an open source licence. It is not yet defined (probably Apache V2 licence).

## Project status
The project is currently in development.
